@@ -1,7 +1,7 @@
 # coding: utf-8
 """
-Mock objects
-------------
+Module ``mock``
+---------------
 
 Wrapper to unittest.mock reducing the boilerplate when testing asyncio powered
 code.
@@ -52,6 +52,7 @@ if sys.version_info >= (3, 5):
         return __aiter__
 
     unittest.mock._side_effect_methods["__aiter__"] = _get_async_iter
+    unittest.mock._all_magics |= _async_magics
 else:
     _awaitable = None
     async_magic_coroutines = _async_magics = set()
@@ -130,6 +131,8 @@ def _set_is_coroutine(self, value):
     self.__dict__['_mock_is_coroutine'] = value
 
 
+# _mock_add_spec() is the actual private implementation in unittest.mock, we
+# override it to support coroutines in the metaclass.
 def _mock_add_spec(self, spec, *args, **kwargs):
     unittest.mock.NonCallableMock._mock_add_spec(self, spec, *args, **kwargs)
 
@@ -191,11 +194,12 @@ class IsCoroutineArgMeta(MockMetaMixin):
                 '_is_coroutine': property(_get_is_coroutine),
             })
 
-            def __setattr__(self, name, value):
-                if name == 'is_coroutine':
+            wrapped_setattr = namespace.get("__setattr__", base[0].__setattr__)
+            def __setattr__(self, attrname, value):
+                if attrname == 'is_coroutine':
                     self._asynctest_set_is_coroutine(value)
                 else:
-                    return base[0].__setattr__(self, name, value)
+                    return wrapped_setattr(self, attrname, value)
 
             namespace['__setattr__'] = __setattr__
 
@@ -779,9 +783,7 @@ def create_autospec(spec, spec_set=False, instance=False, _parent=None,
                       'assert_any_await',
                       'assert_has_awaits',
                       'assert_not_awaited'):
-                def f(*args, **kwargs):
-                    return getattr(wrapped_mock, a)(*args, **kwargs)
-                setattr(mock, a, f)
+                setattr(mock, a, getattr(wrapped_mock, a))
     else:
         unittest.mock._check_signature(spec, mock, is_type, instance)
 
